Drawing

Struct Drawing 

pub struct Drawing { /* private fields */ }
The drawing contains

Implementations

Source

impl Drawing

pub fn new() -> Self

pub fn forward(&mut self, pen: &mut Pen, distance: Distance)

Move by distance forward from pen with the same angle

pub fn backward(&mut self, pen: &mut Pen, distance: Distance)

Move by distance backward from pen with the same angle

pub fn set_background_color<C: Into<Color>>(&mut self, color: C)

Change the background color

pub fn set_size<S: Into<Size>>(&mut self, size: S)

Change the drawing size

pub fn set_center<P: Into<DrawingPos>>(&mut self, positon: P)

Centering the drawing

pub fn save_svg(&mut self, path: &str)

Parse self.composer and write lines into a file at path