Pos

Struct Pos 

pub struct Pos<T: Sized + Add + Mul + Div + Sub>(pub T, pub T);
Location on the plan (x, y)

Tuple Fields

0: T1: T

Implementations

Source

impl Pos<i16>

pub fn next_pos_turn(&self, t: Angle, a: Angle, d: Distance) -> Pos<i16>

Return another Pos depending of an angle and a Pos

t is the heading angle

a is the turn angle

d is the distance

Source

impl Pos<i32>

pub fn next_pos_turn(&self, t: Angle, a: Angle, d: Distance) -> Pos<i32>

Return another Pos depending of an angle and a Pos

t is the heading angle

a is the turn angle

d is the distance

Source

impl Pos<i64>

pub fn next_pos_turn(&self, t: Angle, a: Angle, d: Distance) -> Pos<i64>

Return another Pos depending of an angle and a Pos

t is the heading angle

a is the turn angle

d is the distance

Source

impl Pos<i128>

pub fn next_pos_turn(&self, t: Angle, a: Angle, d: Distance) -> Pos<i128>

Return another Pos depending of an angle and a Pos

t is the heading angle

a is the turn angle

d is the distance

Source

impl Pos<f64>

pub fn next_pos_turn(&self, t: Angle, a: Angle, d: Distance) -> Pos<f64>

Return another Pos depending of an angle and a Pos

t is the heading angle

a is the turn angle

d is the distance