pub struct Drawing { /* private fields */ }Expand description
The drawing contains
Implementations
Sourceimpl Drawing
impl Drawing
pub fn new() -> Self
Sourcepub fn forward(&mut self, pen: &mut Pen, distance: Distance)
pub fn forward(&mut self, pen: &mut Pen, distance: Distance)
Move by distance forward from pen with the same angle
Sourcepub fn backward(&mut self, pen: &mut Pen, distance: Distance)
pub fn backward(&mut self, pen: &mut Pen, distance: Distance)
Move by distance backward from pen with the same angle
Sourcepub fn set_background_color<C: Into<Color>>(&mut self, color: C)
pub fn set_background_color<C: Into<Color>>(&mut self, color: C)
Change the background color
Sourcepub fn set_center<P: Into<DrawingPos>>(&mut self, positon: P)
pub fn set_center<P: Into<DrawingPos>>(&mut self, positon: P)
Centering the drawing